@@ -95,6 +95,7 @@ public Q_SLOTS:
     void dismissCurrent();
     /*reimp*/
     void accept() override;
+    void reject() override;
 
     /**
        If an incidence changed, for example in korg, we must update
@@ -134,13 +135,14 @@ private:
     ReminderList selectedItems() const;
     void toggleDetails(QTreeWidgetItem *item);
     void showDetails(QTreeWidgetItem *item);
+    static bool grabFocus();
 
     Akonadi::ETMCalendar::Ptr mCalendar;
     QTreeWidget *mIncidenceTree = nullptr;
     CalendarSupport::IncidenceViewer *mDetailView = nullptr;
     KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
 
-    QPoint mPos;
+    QRect mRect;
     QSpinBox *mSuspendSpin = nullptr;
     KComboBox *mSuspendUnit = nullptr;
     QMenu *mSuspendMenu = nullptr;
