@@ -44,6 +44,7 @@ AlarmDockWindow::AlarmDockWindow()
     KConfigGroup config(KSharedConfig::openConfig(), "General");
     const bool autostartSet = config.hasKey("Autostart");
     const bool autostart = config.readEntry("Autostart", true);
+    const bool grabFocus = config.readEntry("GrabFocus", false);
     const bool alarmsEnabled = config.readEntry("Enabled", true);
 
     mName = i18nc("@title:window", "KOrganizer Reminder Daemon");
@@ -70,11 +71,17 @@ AlarmDockWindow::AlarmDockWindow()
 
     // Set up the context menu
     mSuspendAll
-        = contextMenu()->addAction(i18nc("@action:inmenu", "Suspend All Reminders"), this,
+        = contextMenu()->addAction(i18nc("@action:inmenu", "&Suspend All Reminders"), this,
                                    &AlarmDockWindow::slotSuspendAll);
     mDismissAll
-        = contextMenu()->addAction(i18nc("@action:inmenu", "Dismiss All Reminders"), this,
+        = contextMenu()->addAction(i18nc("@action:inmenu", "&Dismiss All Reminders"), this,
                                    &AlarmDockWindow::slotDismissAll);
+    // leave mShow always enabled that way you can get to alarms that are
+    // suspended and inactive to dismiss them before they go off again
+    // (as opposed to the other two that are initially disabled)
+    mShow
+        = contextMenu()->addAction(i18nc("@action:inmenu", "Show &Reminders"), this,
+                                   &AlarmDockWindow::showReminderSignal);
     mSuspendAll->setEnabled(false);
     mDismissAll->setEnabled(false);
 
@@ -92,6 +99,17 @@ AlarmDockWindow::AlarmDockWindow()
     mAlarmsEnabled->setChecked(alarmsEnabled);
     mAutostart->setChecked(autostart);
 
+    mGrabFocus =
+        contextMenu()->addAction(i18nc( "@action:inmenu", "Reminder Requests Focus"));
+    mGrabFocus->setToolTip(i18nc("@info:tooltip",
+                                 "When this option is enabled the reminder dialog will "
+                                 "automatically receive keyboard focus when it opens."));
+    connect(mGrabFocus, &QAction::toggled, this, &AlarmDockWindow::toggleGrabFocus);
+    // ToolTips aren't enabled for menus by default.
+    contextMenu()->setToolTipsVisible(true);
+    mGrabFocus->setCheckable(true);
+    mGrabFocus->setChecked(grabFocus);
+
     // Disable standard quit behaviour. We have to intercept the quit even,
     // if the main window is hidden.
     QAction *act = action(QStringLiteral("quit"));
@@ -139,6 +157,12 @@ void AlarmDockWindow::toggleAutostart(bool checked)
     enableAutostart(checked);
 }
 
+void AlarmDockWindow::toggleGrabFocus(bool checked)
+{
+    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    config.writeEntry("GrabFocus", checked);
+}
+
 void AlarmDockWindow::slotSuspendAll()
 {
     Q_EMIT suspendAllSignal();
